@@ -1,4 +1,4 @@
-import os,datetime
+import os, datetime
 
 from datetime import timedelta
 
@@ -12,9 +12,9 @@ class Command(BaseCommand):
     help = 'Clean all temporary attachments loaded to MultiuploaderFile model'
 
     def handle(self, *args, **options):
-        expiration_time = getattr(settings, "MULTIUPLOADER_FILE_EXPIRATION_TIME", DEFAULTS.EXPIRATION_TIME)
+        expiration_time = getattr(settings, "MULTIUPLOADER_FILE_EXPIRATION_TIME", DEFAULTS.MULTIUPLOADER_FILE_EXPIRATION_TIME)
         time_threshold = datetime.datetime.now() - timedelta(seconds=expiration_time)
-        
+
         for attach in MultiuploaderFile.objects.filter(upload_date__lt=time_threshold):
             try:
                 os.remove(attach.file.path)
@@ -22,5 +22,5 @@ class Command(BaseCommand):
                 print e
 
         MultiuploaderFile.objects.filter(upload_date__lt=time_threshold).delete()
-        
+
         print "Cleaning temporary upload files complete"
